/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef PROWRITER_H
#define PROWRITER_H

#include "namespace_global.h"

#include <QStringList>

QT_BEGIN_NAMESPACE
class QDir;
class ProFile;
QT_END_NAMESPACE

namespace Qt4ProjectManager {
namespace Internal {

class ProWriter
{
public:
    static void addFiles(ProFile *profile, QStringList *lines,
         const QDir &proFileDir, const QStringList &filePaths, const QString &var)
    {
        addVarValues(profile, lines, proFileDir, filePaths, var, true);
    }

    static QStringList removeFiles(ProFile *profile, QStringList *lines,
        const QDir &proFileDir, const QStringList &filePaths,
        const QStringList &vars)
    {
        return removeVarValues(profile, lines, proFileDir, filePaths, vars, true);
    }

    static void addVarValues(ProFile *profile, QStringList *lines,
        const QDir &proFileDir, const QStringList &values, const QString &var)
    {
        addVarValues(profile, lines, proFileDir, values, var, false);
    }

    static QStringList removeVarValues(ProFile *profile, QStringList *lines,
        const QDir &proFileDir, const QStringList &values,
        const QStringList &vars)
    {
        return removeVarValues(profile, lines, proFileDir, values, vars, false);
    }

private:

    static void addVarValues(ProFile *profile, QStringList *lines,
        const QDir &proFileDir, const QStringList &values, const QString &var,
        bool valuesAreFiles);

    static QStringList removeVarValues(ProFile *profile, QStringList *lines,
        const QDir &proFileDir, const QStringList &values,
        const QStringList &vars, bool valuesAreFiles);
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // PROWRITER_H
